@@ -21,10 +21,35 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE."""
 # <=========>
 
-from .common.tools import get_filename,clean_old_log
-from .server import *
-# from .server_async import *
+from .common.tools import get_filename, clean_old_log, dbg, get_obj_name
+from .db.no_sql.redis.redis_client_manager import RedisManager
+from .db.sql.async_mysql.db_client_manager import AsyncMySQLManager
+from .db.sql.mysql.db_client_manager import MySQLManager
+from .db.sql.sqlite.db_client_manager import SQLiteManager
+
+AsyncMySQL = AsyncMySQLManager
+MySQL = MySQLManager
+SQLite = SQLiteManager
+Redis = RedisManager
+
+conf_map = {
+
+}
+def auto_init():
+    dbg('自动初始化同步mysql')
+    try:
+        from config.db_config import db_config
+        mysql_pool = MySQL(db_config)
+        dbg('自动初始化同步mysql成功')
+        return mysql_pool
+    except Exception as e:
+        dbg('自动初始化同步mysql失败')
+        dbg(e)
+
+Data = auto_init()
+
+
+__version__ = "8.1.0"
 
-__version__ = "7.1.5"
 
 
